# plover-ninja

![Ninja Dolores](/images/dolores-ninja.png "Dolores Ninja")

## What the ninja can do for you

Suppose you're steno-ing away and you come across a tricky word.

- Maybe the translation is hard to remember
- Maybe the hand shape is hard to form
- Maybe you can't remember the translation at all and you need to fingerspell

It's okay, this happens, and you can keep moving, but you also have this nagging feeling that you'd like to try to capture that word so you can revisit it later and smooth out the speed bump.

- You could pause to write down the word, but this can interrupt your flow
- You can ignore the word, but then you risk bumping into the same bump over and over

If only there was something that could see this practice opportunity for you and squirrel away that information so that you could come back to it later...
